==> haskell-servant-0.16.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.16.2
id: servant-0.16.2-9Ya18aBWbjjKiiX0IK2c6g
key: servant-0.16.2-9Ya18aBWbjjKiiX0IK2c6g
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: e803fd61b81360d8d8cb5fbc7255f4db
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Generic
    Servant.API.Header Servant.API.HttpVersion
    Servant.API.Internal.Test.ComprehensiveAPI Servant.API.IsSecure
    Servant.API.Modifiers Servant.API.QueryParam Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-0.16.2
hs-libraries: HSservant-0.16.2-9Ya18aBWbjjKiiX0IK2c6g
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.6.0-Idz88Vw0zug9yYFt0rn4Ut
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bifunctors-5.5.5-B9uCrLlHHzRLLgqunxnstR bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk deepseq-1.4.4.0
    http-api-data-0.4.1.1-3i7PQtKhnfD9rNT07y7DSn
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-Coz39hkYXV9BhDskHfFaoY
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    singleton-bool-0.1.5-ILc7I2ZiylMBjb8V7CUi6W
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-JZ0YCyq9z4kGqiaSc3dflW
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.16.2-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.16.2
id: servant-0.16.2-8rSpOFoOBcYL2Gyhf9f61c
key: servant-0.16.2-8rSpOFoOBcYL2Gyhf9f61c
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 60e401ecff62088ffc496b88acac0123
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Generic
    Servant.API.Header Servant.API.HttpVersion
    Servant.API.Internal.Test.ComprehensiveAPI Servant.API.IsSecure
    Servant.API.Modifiers Servant.API.QueryParam Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-0.16.2
hs-libraries: HSservant-0.16.2-8rSpOFoOBcYL2Gyhf9f61c
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bifunctors-5.5.6-LlETHLEZDigJhuVw0C0wnJ bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk deepseq-1.4.4.0
    http-api-data-0.4.1.1-B1LvsReVYs7Fz0hm5fLXfF
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    singleton-bool-0.1.5-ILc7I2ZiylMBjb8V7CUi6W
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-K4hdy51uorZLFKZGOl3FPo
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
